@@ -34,10 +34,10 @@ function initPage(){
 	$('#Navi_Button').removeAttr("href");
 	$('#Navi_Button').bind("click", function(){
 		if(g_FunctionListView == "ListSetup"){
-			window.location.href = "1.4.0.0__FunctionsSetupView.html?FunctionIndex=" + g_FunctionIndex;
+			window.location.href = "1.4.0.0__FunctionsSetupView.html?ScrollIndex=" + g_FunctionIndex;
 		}
 		else{
-			window.location.href = "1.4.0__Functions.html?FunctionIndex=" + g_FunctionIndex;
+			window.location.href = "1.4.0__Functions.html?ScrollIndex=" + g_FunctionIndex;
 		}
 	});
 
@@ -271,7 +271,7 @@ function onEVENT_INIT(e){
 				"&ControlPath=" + getControlAssignmentPathRate("Control", g_Function_Control, g_FunctionIndex) +
 				"&ControlId=" + g_Function_Control +
 				"&ControlNode=Control" +
-				"&PageId=3" +
+				"&PageId=1" +
 				"&FromName=" + e.EventData.Function.Item[0].Name;
 		});
 
